aboutsummaryrefslogtreecommitdiffstats
path: root/vendor/ramsey/uuid/src/Builder
diff options
context:
space:
mode:
authorMario <mario@mariovavti.com>2022-05-19 08:18:15 +0000
committerMario <mario@mariovavti.com>2022-05-19 08:18:15 +0000
commit55d833a9c86ad9356e76bf47d0f48dd40552944a (patch)
tree4c5921be76eb249ec623aa576e2d2528537308cf /vendor/ramsey/uuid/src/Builder
parent8ba47450970bab036664f03a558917c13d8c1574 (diff)
downloadvolse-hubzilla-55d833a9c86ad9356e76bf47d0f48dd40552944a.tar.gz
volse-hubzilla-55d833a9c86ad9356e76bf47d0f48dd40552944a.tar.bz2
volse-hubzilla-55d833a9c86ad9356e76bf47d0f48dd40552944a.zip
update composer libs
Diffstat (limited to 'vendor/ramsey/uuid/src/Builder')
-rw-r--r--vendor/ramsey/uuid/src/Builder/BuilderCollection.php5
-rw-r--r--vendor/ramsey/uuid/src/Builder/FallbackBuilder.php6
2 files changed, 8 insertions, 3 deletions
diff --git a/vendor/ramsey/uuid/src/Builder/BuilderCollection.php b/vendor/ramsey/uuid/src/Builder/BuilderCollection.php
index 89fa1e3c8..9df3110fd 100644
--- a/vendor/ramsey/uuid/src/Builder/BuilderCollection.php
+++ b/vendor/ramsey/uuid/src/Builder/BuilderCollection.php
@@ -27,6 +27,11 @@ use Traversable;
/**
* A collection of UuidBuilderInterface objects
*
+ * @deprecated this class has been deprecated, and will be removed in 5.0.0. The use-case for this class comes from
+ * a pre-`phpstan/phpstan` and pre-`vimeo/psalm` ecosystem, in which type safety had to be mostly enforced
+ * at runtime: that is no longer necessary, now that you can safely verify your code to be correct, and use
+ * more generic types like `iterable<T>` instead.
+ *
* @extends AbstractCollection<UuidBuilderInterface>
*/
class BuilderCollection extends AbstractCollection
diff --git a/vendor/ramsey/uuid/src/Builder/FallbackBuilder.php b/vendor/ramsey/uuid/src/Builder/FallbackBuilder.php
index 470d2f755..8ab438a19 100644
--- a/vendor/ramsey/uuid/src/Builder/FallbackBuilder.php
+++ b/vendor/ramsey/uuid/src/Builder/FallbackBuilder.php
@@ -28,14 +28,14 @@ use Ramsey\Uuid\UuidInterface;
class FallbackBuilder implements UuidBuilderInterface
{
/**
- * @var BuilderCollection
+ * @var iterable<UuidBuilderInterface>
*/
private $builders;
/**
* @param BuilderCollection $builders An array of UUID builders
*/
- public function __construct(BuilderCollection $builders)
+ public function __construct(iterable $builders)
{
$this->builders = $builders;
}
@@ -28,14 +28,14 @@ use Ramsey\Uuid\UuidInterface;
private $builders;
/**
- * @param BuilderCollection $builders An array of UUID builders
+ * @param iterable<UuidBuilderInterface> $builders An array of UUID builders
*/